@@ -33,6 +33,7 @@ class Global:
         self.headless = desired_caps.pop('headless', False)
         self.snapshot = desired_caps.pop('snapshot', False)
         self.executable_path = desired_caps.pop('executable_path', False)
+        self.chrome_path = desired_caps.pop('chrome_path', False)
 
 
     def set_driver(self):
@@ -136,6 +137,24 @@ class Global:
                 _app = Application(_backend).connect(path=_path)
                 self.windows['#'] = Windows(_app)
 
+        elif self.platform.lower() == 'linux':
+            options = webdriver.ChromeOptions()
+            options.add_argument('--no-sandbox')
+            options.add_argument('--headless')
+            options.add_argument('--disable-dev-shm-usage')
+            # 设置屏蔽chrome的密码保存提示
+            prefs = {}
+            prefs["credentials_enable_service"] = False
+            prefs["profile.password_manager_enabled"] = False
+            options.add_experimental_option("prefs", prefs)
+            if self.chrome_path:
+                options.binary_location = self.chrome_path
+            if self.executable_path:
+                self.driver = webdriver.Chrome(
+                    options=options, executable_path=self.executable_path)
+            else:
+                self.driver = webdriver.Chrome(options=options)
+
 
     def plan_end(self):
         self.plan_data['plan'] = self.plan_name
